@@ -6,7 +6,7 @@ from plotman import plot_util
 from plotman.plot_util import GB
 
 
-def test_human_format():
+def test_human_format() -> None:
     assert (plot_util.human_format(3442000000, 0) == '3G')
     assert (plot_util.human_format(3542000, 2) == '3.54M')
     assert (plot_util.human_format(354, 0) == '354')
@@ -15,7 +15,7 @@ def test_human_format():
     assert (plot_util.human_format(422399296143, 2) == '422.40G')
     assert (plot_util.human_format(422399296143, 2, True) == '393.39Gi')
 
-def test_time_format():
+def test_time_format() -> None:
     assert (plot_util.time_format(34) == '34s')
     assert (plot_util.time_format(59) == '59s')
     assert (plot_util.time_format(60) == '0:01')
@@ -23,7 +23,7 @@ def test_time_format():
     assert (plot_util.time_format(120) == '0:02')
     assert (plot_util.time_format(3694) == '1:01')
 
-def test_split_path_prefix():
+def test_split_path_prefix() -> None:
     assert (plot_util.split_path_prefix( [] ) ==
             ('', []) )
     assert (plot_util.split_path_prefix([ '/a/0', '/b/1', '/c/2' ]) ==
@@ -31,7 +31,7 @@ def test_split_path_prefix():
     assert ( plot_util.split_path_prefix([ '/a/b/0', '/a/b/1', '/a/b/2' ]) ==
             ('/a/b', ['0', '1', '2']) )
 
-def test_columns():
+def test_columns() -> None:
     assert (plot_util.column_wrap(list(range(8)), 3, filler='--') ==
             [ [ 0, 3, 6 ],
               [ 1, 4, 7 ],
@@ -45,7 +45,7 @@ def test_columns():
               [ 1 ],
               [ 2 ] ] )
 
-def test_list_k32_plots(fs: pyfakefs.fake_filesystem.FakeFilesystem):
+def test_list_plots(fs: pyfakefs.fake_filesystem.FakeFilesystem) -> None:
     fs.create_file('/t/plot-k32-0.plot', st_size=108 * GB)
     fs.create_file('/t/plot-k32-1.plot', st_size=108 * GB)
     fs.create_file('/t/.plot-k32-2.plot', st_size=108 * GB)
@@ -53,13 +53,17 @@ def test_list_k32_plots(fs: pyfakefs.fake_filesystem.FakeFilesystem):
     fs.create_file('/t/plot-k32-4.plot', st_size=100 * GB)
     fs.create_file('/t/plot-k32-5.plot', st_size=108 * GB)
 
-    assert (plot_util.list_k32_plots('/t/') ==
+    fs.create_file('/t/plot-k33-6.plot', st_size=108 * GB)
+    fs.create_file('/t/plot-k33-7.plot', st_size=216 * GB)
+
+    assert (plot_util.list_plots('/t/') ==
             [ '/t/plot-k32-0.plot',
               '/t/plot-k32-1.plot',
-              '/t/plot-k32-5.plot' ] )
+              '/t/plot-k32-5.plot',
+              '/t/plot-k33-7.plot' ] )
 
 
-def test_get_plotsize():
+def test_get_plotsize() -> None:
     assert (
         [659272492, 107287518791, 221143636517, 455373353413, 936816632588]
         == [plot_util.get_plotsize(n) for n in [25, 32, 33, 34, 35]]
