@@ -73,6 +73,8 @@ def get_validated_configs(config_text: str, config_path: str, preset_target_defi
 
     if loaded.plotting.type == "chia":
         if loaded.plotting.chia is None:
+            # TODO: fix all the `TODO: use the configured executable` so this is not
+            #       needed.
             raise ConfigurationException(
                 "chia selected as plotter but plotting: chia: was not specified in the config",
             )
@@ -81,6 +83,12 @@ def get_validated_configs(config_text: str, config_path: str, preset_target_defi
             raise ConfigurationException(
                 "Chia Network plotter accepts up to one of plotting: pool_pk: and pool_contract_address: but both are specified",
             )
+
+        executable_name = os.path.basename(loaded.plotting.chia.executable)
+        if executable_name != "chia":
+            raise ConfigurationException(
+                "plotting: chia: executable: must refer to an executable named chia"
+            )
     elif loaded.plotting.type == "madmax":
         if loaded.plotting.madmax is None:
             raise ConfigurationException(
@@ -101,6 +109,14 @@ def get_validated_configs(config_text: str, config_path: str, preset_target_defi
                 "madMAx plotter accepts only one of plotting: pool_pk: and pool_contract_address: but both are specified",
             )
 
+        executable_name = os.path.basename(loaded.plotting.madmax.executable)
+        if executable_name != "chia_plot":
+            # TODO: fix all the `TODO: use the configured executable` so this is not
+            #       needed.
+            raise ConfigurationException(
+                "plotting: madmax: executable: must refer to an executable named chia_plot"
+            )
+
     if loaded.archiving is not None:
         preset_target_objects = yaml.safe_load(preset_target_definitions_text)
         preset_target_schema = desert.schema(PresetTargetDefinitions)
@@ -312,6 +328,7 @@ class Scheduling:
 
 @attr.frozen
 class ChiaPlotterOptions:
+    executable: str = "chia"
     n_threads: int = 2
     n_buckets: int = 128
     k: Optional[int] = 32
@@ -321,6 +338,7 @@ class ChiaPlotterOptions:
 
 @attr.frozen
 class MadmaxPlotterOptions:
+    executable: str = "chia_plot"
     n_threads: int = 4
     n_buckets: int = 256
 
@@ -369,9 +387,15 @@ class PlotmanConfig:
     @contextlib.contextmanager
     def setup(self) -> Generator[None, None, None]:
         if self.plotting.type == 'chia':
+            if self.plotting.chia is None:
+                message = (
+                    "internal plotman error, please report the full traceback and your"
+                    + " full configuration file"
+                )
+                raise Exception(message)
             if self.plotting.pool_contract_address is not None:
                 completed_process = subprocess.run(
-                    args=['chia', 'version'],
+                    args=[self.plotting.chia.executable, 'version'],
                     capture_output=True,
                     check=True,
                     encoding='utf-8',
@@ -384,9 +408,16 @@ class PlotmanConfig:
                         f' plots but found: {version}'
                     )
         elif self.plotting.type == 'madmax':
+            if self.plotting.madmax is None:
+                message = (
+                    "internal plotman error, please report the full traceback and your"
+                    + " full configuration file"
+                )
+                raise Exception(message)
+
             if self.plotting.pool_contract_address is not None:
                 completed_process = subprocess.run(
-                    args=['chia_plot', '--help'],
+                    args=[self.plotting.madmax.executable, '--help'],
                     capture_output=True,
                     check=True,
                     encoding='utf-8',
